
**rulemanager** | AWS CloudWatch Rule Configurator
------------------------------------------------------------------

PACKAGE: rulemanager 


**rulemanager**:

    * CloudWatch Rule Status Viewer & Configurator
    * Python3 commandline utility.

**Features**:

    * Toggle CloudWatch Rule Enable/ Disable
    * Update rule trigger time
    * Called by deployment logic
    * User customizable
